Crate gen_converter

这一层的主要目的在于当解析gen文件获取到Basic AST之后,根据Basic AST的内容生成GenUI的AST (GenUI文件模型) See test_converter

Structs

Model
GenUI文件模型
Parent
SugarProps
GenUI组件属性的语法糖
TemplateModel
GenUI组件模型

Enums

ConvertResult

Functions

file_data

Type Aliases

Callbacks
事件回调集合
ConvertStyle
also name ConvertStyle in gen-ui no difference between style and props so we use the same struct to represent them <id|class, HashMap<prop, value>>
PropTree
记录组件中是否有绑定的属性和事件 这个类型会记录下组件树中所有的绑定属性和事件, 使用TemplateModel.get_props_tree()获取 返回结果为双元素元组,第一个元素是绑定属性,第二个元素是绑定事件 Vec<(($widget_name, $widget_id), Some({key:PropsKey, value: Value}))>